from enum import IntEnum, unique


@unique
class LoadoutSlot(IntEnum):
    """
    An Enum referencing the different slots in CS:GO's item loadout
    """
    M4A1_S = 3222208572
    M4A4 = 3222208528
    GLOCK_18 = 2147614720
    USP_S = 3221356605
    P2000 = 3221356576
    DUAL_BERETTAS_CT = 3221422080
    DUAL_BERETTAS_T = 2147680256
    P250_CT = 3221487616
    P250_T = 2147745792
    CZ75_CT = 3221553215
    CZ75_T = 2147811391
    FIVE_SEVEN = 3221553155
    TEC_9 = 2147811358
    DEAGLE_T = 2147876865
    REVOLVER_CT = 3221618752
    REVOLVER_T = 2147876928
    DEAGLE_CT = 3221618689
    MP9 = 3221749760
    MP7_CT = 3221815329
    P90_CT = 3221946368
    MP5_CT = 3221815319
    PP_BIZON_CT = 3222011904
    UMP_45_CT = 3221880832
    MAC_10 = 2148007936
    MP7_T = 2148073505
    MP5_T = 2148073495
    UMP_45_T = 2148139008
    P90_T = 2148204544
    PP_BIZON_T = 2148270080
    FAMAS = 3222142976
    AUG = 3222339584
    SSG_08_CT = 3222274048
    AWP_CT = 3222405120
    SCAR_20 = 3222470656
    GALIL_AR = 2148401152
    AK_47 = 2148466688
    SSG_08_T = 2148532224
    SG_553 = 2148597760
    G3SG1 = 2148728832
    AWP_T = 2148663296
    NOVA_T = 2148794368
    XM1014_T = 2148859904
    SAWED_OFF = 2148925440
    M249_T = 2148990976
    NEGEV_T = 2149056512
    NOVA_CT = 3222536192
    XM1014_CT = 3222601728
    MAG_7 = 3222667264
    M249_CT = 3222732800
    NEGEV_CT = 3222798336
    AGENT_T = 2149974016
    AGENT_CT = 3223715840
    KNIFE_CT = 3221225472
    KNIFE_T = 2147483648
    MUSIC_KIT = 3538944
    GLOVES_T = 2150170624
    GLOVES_CT = 3223912448
